@@ -1,11 +1,14 @@
 """Run a mock zwave-js-server instance off of a network state dump."""
+
+from __future__ import annotations
+
 import argparse
 import asyncio
-import json
-import logging
 from collections import defaultdict
 from collections.abc import Hashable
-from typing import Any, DefaultDict, List, Optional, Union
+import json
+import logging
+from typing import Any
 
 from aiohttp import WSMsgType, web, web_request
 
@@ -26,12 +29,15 @@ class HashableDict(dict):
     """Dictionary that can be used as a key in a dictionary."""
 
     def __key(self) -> tuple:
+        """Return key representation of HashableDict."""
         return tuple((k, self[k]) for k in sorted(self))
 
     def __hash__(self) -> int:  # type: ignore
+        """Return hash representation of HashableDict."""
         return hash(self.__key())
 
     def __eq__(self, other: Any) -> bool:
+        """Return whether HashableDict is equal to other."""
         # pylint: disable=protected-access
         return isinstance(other, HashableDict) and self.__key() == other.__key()
 
@@ -45,9 +51,9 @@ class MockZwaveJsServer:
 
     def __init__(
         self,
-        network_state_dump: List[dict],
-        events_to_replay: List[dict],
-        command_results: DefaultDict[HashableDict, list],
+        network_state_dump: list[dict],
+        events_to_replay: list[dict],
+        command_results: defaultdict[HashableDict, list],
     ) -> None:
         """Initialize class."""
         self.network_state_dump = network_state_dump
@@ -58,7 +64,7 @@ class MockZwaveJsServer:
                 web.post("/replay", self.replay_handler),
             ]
         )
-        self.primary_ws_resp: Optional[web.WebSocketResponse] = None
+        self.primary_ws_resp: web.WebSocketResponse | None = None
         self.events_to_replay = events_to_replay
         self.command_results = command_results
 
@@ -77,9 +83,7 @@ class MockZwaveJsServer:
         await self.send_json({**data, "messageId": message_id})
 
     async def send_success_command_result(
-        self,
-        result: Optional[dict],
-        message_id: str,
+        self, result: dict | None, message_id: str
     ) -> None:
         """Send success message."""
         if result is None:
@@ -93,7 +97,7 @@ class MockZwaveJsServer:
         if record.get("record_type") not in ("event", "command"):
             raise TypeError(f"Malformed record: {record}")
         if record["record_type"] == "event":
-            await self.send_json(record["data"])
+            await self.send_json(record["event_msg"])
         else:
             add_command_result(self.command_results, record)
 
@@ -107,10 +111,12 @@ class MockZwaveJsServer:
 
         version_info: VersionInfoDataType = self.network_state_dump[0]
         # adjust min/max schemas if needed to get things to work
-        if MAX_SERVER_SCHEMA_VERSION > version_info["maxSchemaVersion"]:
-            version_info["maxSchemaVersion"] = MAX_SERVER_SCHEMA_VERSION
-        if MIN_SERVER_SCHEMA_VERSION < version_info["minSchemaVersion"]:
-            version_info["minSchemaVersion"] = MIN_SERVER_SCHEMA_VERSION
+        version_info["maxSchemaVersion"] = max(
+            MAX_SERVER_SCHEMA_VERSION, version_info["maxSchemaVersion"]
+        )
+        version_info["minSchemaVersion"] = min(
+            MIN_SERVER_SCHEMA_VERSION, version_info["minSchemaVersion"]
+        )
         await self.send_json(version_info)
 
         async for msg in ws_resp:
@@ -136,7 +142,7 @@ class MockZwaveJsServer:
 
                 cmd = data["command"]
                 message_id = data["messageId"]
-                if cmd == "set_api_schema":
+                if cmd == "initialize":
                     await self.send_json(self.network_state_dump[1])
                 elif cmd == "driver.get_log_config":
                     await self.send_success_command_result(
@@ -194,7 +200,7 @@ class MockZwaveJsServer:
         return web.Response(status=200)
 
 
-def _hashable_value(item: Union[dict, list, Hashable]) -> Union[tuple, list, Hashable]:
+def _hashable_value(item: dict | list | Hashable) -> tuple | list | Hashable:
     """Return hashable value from item."""
     if isinstance(item, dict):
         return make_dict_hashable(item)
@@ -221,7 +227,7 @@ def sanitize_msg(msg: dict) -> HashableDict:
 
 
 def add_command_result(
-    command_results: DefaultDict[HashableDict, list],
+    command_results: defaultdict[HashableDict, list],
     record: dict,
 ) -> None:
     """Add a command result to command_results map."""
@@ -241,7 +247,7 @@ def add_command_result(
 
 def get_args() -> argparse.Namespace:
     """Get arguments."""
-    parser = argparse.ArgumentParser(description="Dump Instance")
+    parser = argparse.ArgumentParser(description="Mock Z-Wave JS Server")
     parser.add_argument(
         "network_state_path", type=str, help="File path to network state dump JSON."
     )
@@ -252,7 +258,7 @@ def get_args() -> argparse.Namespace:
     parser.add_argument(
         "--log-level",
         type=str.upper,
-        help="Log level",
+        help="Log level for the mock server instance",
         default="INFO",
         choices=["DEBUG", "INFO", "WARNING", "ERROR"],
     )
@@ -292,15 +298,15 @@ def main() -> None:
     """Run main entrypoint."""
     args = get_args()
 
-    with open(args.network_state_path, "r", encoding="utf8") as fp:
-        network_state_dump: List[dict] = json.load(fp)
+    with open(args.network_state_path, encoding="utf8") as fp:
+        network_state_dump: list[dict] = json.load(fp)
 
     events_to_replay = []
-    command_results: DefaultDict[HashableDict, list] = defaultdict(list)
+    command_results: defaultdict[HashableDict, list] = defaultdict(list)
 
     if args.combined_replay_dump_path:
-        with open(args.combined_replay_dump_path, "r", encoding="utf8") as fp:
-            records: List[dict] = json.load(fp)
+        with open(args.combined_replay_dump_path, encoding="utf8") as fp:
+            records: list[dict] = json.load(fp)
 
             for record in records:
                 if record.get("record_type") not in ("event", "command"):
@@ -308,12 +314,12 @@ def main() -> None:
                         f"Invalid record in combined replay dump file: {record}"
                     )
                 if record["record_type"] == "event":
-                    events_to_replay.append(record["data"])
+                    events_to_replay.append(record["event_msg"])
                 else:
                     add_command_result(command_results, record)
 
     if args.events_to_replay_path:
-        with open(args.events_to_replay_path, "r", encoding="utf8") as fp:
+        with open(args.events_to_replay_path, encoding="utf8") as fp:
             records = json.load(fp)
             if (
                 bad_record := next(
@@ -328,10 +334,10 @@ def main() -> None:
                 raise ExitException(
                     f"Malformed record in events to replay file: {bad_record}"
                 )
-            events_to_replay.extend([record["data"] for record in records])
+            events_to_replay.extend([record["event_msg"] for record in records])
 
     if args.command_results_path:
-        with open(args.command_results_path, "r", encoding="utf8") as fp:
+        with open(args.command_results_path, encoding="utf8") as fp:
             records = json.load(fp)
             if (
                 bad_record := next(
