@@ -28,7 +28,6 @@ from zwave_js_server.model import (
     controller as controller_pkg,
 )
 from zwave_js_server.model.controller import Controller
-from zwave_js_server.model.controller.firmware import ControllerFirmwareUpdateStatus
 from zwave_js_server.model.controller.rebuild_routes import (
     RebuildRoutesOptions,
     RebuildRoutesStatus,
@@ -1877,6 +1876,22 @@ async def test_get_rf_region(controller, uuid4, mock_command):
     }
 
 
+async def test_toggle_rf(controller, uuid4, mock_command):
+    """Test toggle RF."""
+    ack_commands = mock_command(
+        {"command": "controller.toggle_rf"},
+        {"success": True},
+    )
+    assert await controller.async_toggle_rf(True)
+
+    assert len(ack_commands) == 1
+    assert ack_commands[0] == {
+        "command": "controller.toggle_rf",
+        "enable": True,
+        "messageId": uuid4,
+    }
+
+
 async def test_get_known_lifeline_routes(
     multisensor_6, ring_keypad, wallmote_central_scene, uuid4, mock_command
 ):
@@ -2227,48 +2242,6 @@ async def test_inclusion_aborted(controller):
     assert {k: v for k, v in event.data.items() if k != "controller"} == event_data
 
 
-async def test_firmware_events(controller):
-    """Test firmware events."""
-    assert controller.firmware_update_progress is None
-    event = Event(
-        type="firmware update progress",
-        data={
-            "source": "controller",
-            "event": "firmware update progress",
-            "progress": {
-                "sentFragments": 1,
-                "totalFragments": 10,
-                "progress": 10.0,
-            },
-        },
-    )
-
-    controller.receive_event(event)
-    progress = event.data["firmware_update_progress"]
-    assert progress.sent_fragments == 1
-    assert progress.total_fragments == 10
-    assert progress.progress == 10.0
-    assert controller.firmware_update_progress
-    assert controller.firmware_update_progress.sent_fragments == 1
-    assert controller.firmware_update_progress.total_fragments == 10
-    assert controller.firmware_update_progress.progress == 10.0
-
-    event = Event(
-        type="firmware update finished",
-        data={
-            "source": "controller",
-            "event": "firmware update finished",
-            "result": {"status": 255, "success": True},
-        },
-    )
-
-    controller.receive_event(event)
-    result = event.data["firmware_update_finished"]
-    assert result.status == ControllerFirmwareUpdateStatus.OK
-    assert result.success
-    assert controller.firmware_update_progress is None
-
-
 async def test_unknown_event(controller):
     """Test that an unknown event type causes an exception."""
     with pytest.raises(KeyError):
