@@ -11,6 +11,7 @@ from zwave_js_server.model import (
     log_config as log_config_pkg,
     log_message as log_message_pkg,
 )
+from zwave_js_server.model.driver.firmware import DriverFirmwareUpdateStatus
 
 from .. import load_fixture
 
@@ -409,3 +410,45 @@ def test_config_manager(driver):
     """Test the driver has the config manager property."""
     assert driver.config_manager is not None
     assert driver.config_manager._client is driver.client
+
+
+async def test_firmware_events(driver):
+    """Test firmware events."""
+    assert driver.firmware_update_progress is None
+    event = Event(
+        type="firmware update progress",
+        data={
+            "source": "driver",
+            "event": "firmware update progress",
+            "progress": {
+                "sentFragments": 1,
+                "totalFragments": 10,
+                "progress": 10.0,
+            },
+        },
+    )
+
+    driver.receive_event(event)
+    progress = event.data["firmware_update_progress"]
+    assert progress.sent_fragments == 1
+    assert progress.total_fragments == 10
+    assert progress.progress == 10.0
+    assert driver.firmware_update_progress
+    assert driver.firmware_update_progress.sent_fragments == 1
+    assert driver.firmware_update_progress.total_fragments == 10
+    assert driver.firmware_update_progress.progress == 10.0
+
+    event = Event(
+        type="firmware update finished",
+        data={
+            "source": "driver",
+            "event": "firmware update finished",
+            "result": {"status": 255, "success": True},
+        },
+    )
+
+    driver.receive_event(event)
+    result = event.data["firmware_update_finished"]
+    assert result.status == DriverFirmwareUpdateStatus.OK
+    assert result.success
+    assert driver.firmware_update_progress is None
