@@ -965,17 +965,28 @@ class Node(EventBase):
 
     async def async_set_raw_config_parameter_value(
         self,
-        new_value: int | str,
+        new_value: int,
         property_: int | str,
         property_key: int | None = None,
         value_size: Literal[1, 2, 4] | None = None,
         value_format: ConfigurationValueFormat | None = None,
-    ) -> tuple[Value, SetConfigParameterResult | None]:
+    ) -> SetConfigParameterResult:
         """Send setRawConfigParameterValue."""
         return await self.endpoints[0].async_set_raw_config_parameter_value(
             new_value, property_, property_key, value_size, value_format
         )
 
+    async def async_get_raw_config_parameter_value(
+        self,
+        property_: int,
+        property_key: int | None = None,
+        allow_unexpected_response: bool | None = None,
+    ) -> int:
+        """Call getRawConfigParameterValue."""
+        return await self.endpoints[0].async_get_raw_config_parameter_value(
+            property_, property_key, allow_unexpected_response
+        )
+
     def handle_test_powerlevel_progress(self, event: Event) -> None:
         """Process a test power level progress event."""
         event.data["test_power_level_progress"] = TestPowerLevelProgress(
