@@ -1,4 +1,5 @@
 """Provide a model for the Z-Wave JS node's statistics."""
+
 from __future__ import annotations
 
 from contextlib import suppress
@@ -35,8 +36,8 @@ class NodeStatisticsDataType(TypedDict, total=False):
 class NodeStatistics:
     """Represent a node statistics update."""
 
-    client: "Client"
-    data: NodeStatisticsDataType
+    client: Client = field(repr=False)
+    data: NodeStatisticsDataType = field(repr=False)
     commands_tx: int = field(init=False)
     commands_rx: int = field(init=False)
     commands_dropped_rx: int = field(init=False)
