@@ -1,16 +1,35 @@
 """Provide a model for the Z-Wave JS value."""
+
 from __future__ import annotations
 
+from dataclasses import dataclass, field
+from enum import IntEnum, StrEnum
 from typing import TYPE_CHECKING, Any, TypedDict
 
-from ..const import VALUE_UNKNOWN, CommandClass, ConfigurationValueType
+from ..const import (
+    VALUE_UNKNOWN,
+    CommandStatus,
+    ConfigurationValueType,
+    SetValueStatus,
+    SupervisionStatus,
+)
 from ..event import Event
 from ..util.helpers import parse_buffer
+from .duration import Duration, DurationDataType
 
 if TYPE_CHECKING:
     from .node import Node
 
 
+class ValueType(StrEnum):
+    """Enum with all value types."""
+
+    ANY = "any"
+    BOOLEAN = "boolean"
+    NUMBER = "number"
+    STRING = "string"
+
+
 class MetaDataType(TypedDict, total=False):
     """Represent a metadata data dict type."""
 
@@ -19,16 +38,23 @@ class MetaDataType(TypedDict, total=False):
     writeable: bool  # required
     description: str
     label: str
-    min: int
-    max: int
+    min: int | None
+    max: int | None
     unit: str
-    states: dict[int, str]
+    states: dict[str, str]
     ccSpecific: dict[str, Any]
     valueChangeOptions: list[str]
     allowManualEntry: bool
-    valueSize: int
     stateful: bool
     secret: bool
+    default: int
+    # Configuration Value specific attributes
+    valueSize: int
+    format: int
+    noBulkSupport: bool  # deprecated
+    isAdvanced: bool
+    requiresReInclusion: bool
+    isFromConfig: bool
 
 
 class ValueDataType(TypedDict, total=False):
@@ -38,24 +64,17 @@ class ValueDataType(TypedDict, total=False):
     commandClassName: str  # required
     endpoint: int
     property: int | str  # required
-    propertyName: str
+    propertyName: str  # required
     propertyKey: int | str
     propertyKeyName: str
     value: Any
     newValue: Any
     prevValue: Any
-    metadata: MetaDataType
-    ccVersion: int
+    metadata: MetaDataType  # required
+    ccVersion: int  # required
 
 
-def _init_value(node: "Node", val: ValueDataType) -> "Value" | "ConfigurationValue":
-    """Initialize a Value object from ValueDataType."""
-    if val["commandClass"] == CommandClass.CONFIGURATION:
-        return ConfigurationValue(node, val)
-    return Value(node, val)
-
-
-def _get_value_id_str_from_dict(node: "Node", val: ValueDataType) -> str:
+def _get_value_id_str_from_dict(node: Node, val: ValueDataType) -> str:
     """Return string ID of value from ValueDataType dict."""
     return get_value_id_str(
         node,
@@ -67,7 +86,7 @@ def _get_value_id_str_from_dict(node: "Node", val: ValueDataType) -> str:
 
 
 def get_value_id_str(
-    node: "Node",
+    node: Node,
     command_class: int,
     property_: int | str,
     endpoint: int | None = None,
@@ -165,6 +184,38 @@ class ValueMetadata:
         """Return secret."""
         return self.data.get("secret")
 
+    @property
+    def default(self) -> int | None:
+        """Return default."""
+        return self.data.get("default")
+
+    @property
+    def format(self) -> ConfigurationValueFormat | None:
+        """Return format."""
+        if (format_ := self.data.get("format")) is None:
+            return None
+        return ConfigurationValueFormat(format_)
+
+    @property
+    def no_bulk_support(self) -> bool | None:
+        """Return noBulkSupport."""
+        return self.data.get("noBulkSupport")
+
+    @property
+    def is_advanced(self) -> bool | None:
+        """Return isAdvanced."""
+        return self.data.get("isAdvanced")
+
+    @property
+    def requires_re_inclusion(self) -> bool | None:
+        """Return requiresReInclusion."""
+        return self.data.get("requiresReInclusion")
+
+    @property
+    def is_from_config(self) -> bool | None:
+        """Return isFromConfig."""
+        return self.data.get("isFromConfig")
+
     def update(self, data: MetaDataType) -> None:
         """Update data."""
         self.data.update(data)
@@ -173,7 +224,7 @@ class ValueMetadata:
 class Value:
     """Represent a Z-Wave JS value."""
 
-    def __init__(self, node: "Node", data: ValueDataType) -> None:
+    def __init__(self, node: Node, data: ValueDataType) -> None:
         """Initialize value."""
         self.node = node
         self.data: ValueDataType = {}
@@ -265,18 +316,17 @@ class Value:
     def update(self, data: ValueDataType) -> None:
         """Update data."""
         self.data.update(data)
-        if "newValue" in data:
-            self._value = self.data["value"] = data["newValue"]
-        elif "value" in data:
-            self._value = self.data["value"] = data["value"]
+        self.data.pop("prevValue", None)
+        if "newValue" in self.data:
+            self.data["value"] = self.data.pop("newValue")
+
         if "metadata" in data:
             self._metadata.update(data["metadata"])
 
-        self.data.pop("newValue", None)
-        self.data.pop("prevValue", None)
+        self._value = self.data.get("value")
 
         # Handle buffer dict and json string in value.
-        if self.metadata.type == "buffer":
+        if self._value is not None and self.metadata.type == "buffer":
             self._value = parse_buffer(self._value)
 
 
@@ -287,7 +337,49 @@ class ValueNotification(Value):
     https://zwave-js.github.io/node-zwave-js/#/api/node?id=quotvalue-notificationquot
     """
 
-    # format is the same as a Value message, subclassed for easier identifying and future use
+    # format is the same as a Value message, subclassed for easier identifying and
+    # future use
+
+
+class ConfigurationValueFormat(IntEnum):
+    """Enum of all known configuration value formats."""
+
+    # https://github.com/zwave-js/node-zwave-js/blob/cc_api_options/packages/core/src/values/Metadata.ts#L157
+    SIGNED_INTEGER = 0
+    UNSIGNED_INTEGER = 1
+    ENUMERATED = 2
+    BIT_FIELD = 3
+
+
+class SupervisionResultDataType(TypedDict, total=False):
+    """Represent a Supervision result data dict type."""
+
+    # https://github.com/zwave-js/node-zwave-js/blob/cc_api_options/packages/core/src/consts/Transmission.ts#L311
+    status: int
+    remainingDuration: DurationDataType  # not included unless status is 1 (working)
+
+
+@dataclass
+class SupervisionResult:
+    """Represent a Supervision result type."""
+
+    data: SupervisionResultDataType = field(repr=False)
+    status: SupervisionStatus = field(init=False)
+    remaining_duration: Duration | None = field(init=False, default=None)
+
+    def __post_init__(self) -> None:
+        """Post initialization."""
+        self.status = SupervisionStatus(self.data["status"])
+        if remaining_duration := self.data.get("remainingDuration"):
+            self.remaining_duration = Duration(remaining_duration)
+
+        if self.status == SupervisionStatus.WORKING ^ bool(
+            self.remaining_duration is not None
+        ):
+            raise ValueError(
+                "SupervisionStatus of WORKING requires a remaining duration, all "
+                "other statuses don't include it"
+            )
 
 
 class ConfigurationValue(Value):
@@ -296,17 +388,78 @@ class ConfigurationValue(Value):
     @property
     def configuration_value_type(self) -> ConfigurationValueType:
         """Return configuration value type."""
-        if self.metadata.type == "number":
-            if (
-                self.metadata.allow_manual_entry
-                and not self.metadata.max == self.metadata.min == 0
-            ):
-                return ConfigurationValueType.MANUAL_ENTRY
-            if self.metadata.states:
-                return ConfigurationValueType.ENUMERATED
-            if (
-                self.metadata.max is not None or self.metadata.min is not None
-            ) and not self.metadata.max == self.metadata.min == 0:
-                return ConfigurationValueType.RANGE
+        min_ = self.metadata.min
+        max_ = self.metadata.max
+        states = self.metadata.states
+        allow_manual_entry = self.metadata.allow_manual_entry
+        type_ = self.metadata.type
+
+        if (max_ == 1 and min_ == 0 or type_ == ValueType.BOOLEAN) and not states:
+            return ConfigurationValueType.BOOLEAN
+
+        if (
+            allow_manual_entry
+            and not max_ == min_ == 0
+            and not (max_ is None and min_ is None)
+        ):
+            return ConfigurationValueType.MANUAL_ENTRY
+
+        if states:
+            return ConfigurationValueType.ENUMERATED
+
+        if (max_ is not None or min_ is not None) and not max_ == min_ == 0:
+            return ConfigurationValueType.RANGE
 
         return ConfigurationValueType.UNDEFINED
+
+
+class SetValueResultDataType(TypedDict, total=False):
+    """Represent a setValue result data dict type."""
+
+    # https://github.com/zwave-js/node-zwave-js/blob/v11-dev/packages/cc/src/lib/API.ts#L103
+    status: int  # required
+    remainingDuration: DurationDataType
+    message: str
+
+
+@dataclass
+class SetValueResult:
+    """Result from setValue command."""
+
+    data: SetValueResultDataType = field(repr=False)
+    status: SetValueStatus = field(init=False)
+    remaining_duration: Duration | None = field(init=False)
+    message: str | None = field(init=False)
+
+    def __post_init__(self) -> None:
+        """Post init."""
+        self.status = SetValueStatus(self.data["status"])
+        self.remaining_duration = (
+            Duration(duration_data)
+            if (duration_data := self.data.get("remainingDuration"))
+            else None
+        )
+        self.message = self.data.get("message")
+
+    def __repr__(self) -> str:
+        """Return the representation."""
+        status = self.status.name.replace("_", " ").title()
+        if self.status == SetValueStatus.WORKING:
+            assert self.remaining_duration
+            return f"{status} ({self.remaining_duration})"
+        if self.status in (
+            SetValueStatus.ENDPOINT_NOT_FOUND,
+            SetValueStatus.INVALID_VALUE,
+            SetValueStatus.NOT_IMPLEMENTED,
+        ):
+            assert self.message
+            return f"{status}: {self.message}"
+        return status
+
+
+@dataclass
+class SetConfigParameterResult:
+    """Result of a set config parameter command."""
+
+    status: CommandStatus
+    result: SupervisionResult | SetValueResult | None = None
